@@ -2,13 +2,7 @@
 #define __DICT_ZIP_LIB_H__
 
 #include <zlib.h>
-#include <time.h>
-
-#ifdef __cplusplus
-extern "C"
-{
-#endif				/* __cplusplus */
-
+#include <ctime>
 
 #define DICT_CACHE_SIZE 5
 
@@ -49,13 +43,8 @@ typedef struct dictData {
    dictCache     cache[DICT_CACHE_SIZE];
 } dictData;
 
-dictData *dict_data_open( const char *filename, int computeCRC );
-void dict_data_close( dictData *header );
-void dict_data_read ( dictData *h, char *buffer, unsigned long start, unsigned long size);
+dictData *dict_data_open(const char *filename, int computeCRC);
+void dict_data_close(dictData *header);
+void dict_data_read(dictData *h, char *buffer, unsigned long start, unsigned long size);
 
-#ifdef __cplusplus
-}
-#endif				/* __cplusplus */
-
-
-#endif
+#endif//__DICT_ZIP_LIB_H__
